*******************************
The sherpa.utils.logging module
*******************************

.. currentmodule:: sherpa.utils.logging

.. automodule:: sherpa.utils.logging

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      SherpaVerbosity

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      config_logger

Class Inheritance Diagram
=========================

.. inheritance-diagram:: SherpaVerbosity
   :parts: 1
